"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.updateToWorkspacePackagesFromManifest = updateToWorkspacePackagesFromManifest;
exports.createWorkspaceSpecs = createWorkspaceSpecs;
const error_1 = require("@pnpm/error");
const parse_wanted_dependency_1 = require("@pnpm/parse-wanted-dependency");
function updateToWorkspacePackagesFromManifest(manifest, include, workspacePackages) {
    const allDeps = {
        ...(include.devDependencies ? manifest.devDependencies : {}),
        ...(include.dependencies ? manifest.dependencies : {}),
        ...(include.optionalDependencies ? manifest.optionalDependencies : {}),
    };
    return Object.keys(allDeps)
        .filter(depName => workspacePackages.has(depName))
        .map(depName => `${depName}@workspace:*`);
}
function createWorkspaceSpecs(specs, workspacePackages) {
    return specs.map((spec) => {
        const parsed = (0, parse_wanted_dependency_1.parseWantedDependency)(spec);
        if (!parsed.alias)
            throw new error_1.PnpmError('NO_PKG_NAME_IN_SPEC', `Cannot update/install from workspace through "${spec}"`);
        if (!workspacePackages.has(parsed.alias))
            throw new error_1.PnpmError('WORKSPACE_PACKAGE_NOT_FOUND', `"${parsed.alias}" not found in the workspace`);
        if (!parsed.pref)
            return `${parsed.alias}@workspace:>=0.0.0`;
        if (parsed.pref.startsWith('workspace:'))
            return spec;
        return `${parsed.alias}@workspace:${parsed.pref}`;
    });
}
//# sourceMappingURL=updateWorkspaceDependencies.js.map